# mvcprovider

Create a ***simple MVC*** architecture based on the ***Provider*** package.

## maint.dart

```
    import 'package:flutter/material.dart';
    import 'modules/mycounter/my.counter.dart';

    void main() => runApp(AmazingSample());
    
    class AmazingSample extends StatelessWidget {
      // This widget is the root of this amazing package sample.
      @override
      Widget build(BuildContext context) {
        return MaterialApp(
          title: 'MVC Provider counter demo',
          home: MyCounterModule(),
        );
      }
    }
```

## modules/mycounter/my.counter.dart

```
    import 'package:mvcprovider/mvcprovider.dart';
    
    import 'my.counter.ctrl.dart';
    import 'my.counter.model.dart';
    import 'my.counter.view.dart';

    class MyCounterModule extends Module<MyCounterModel, MyCounterView, MyCounterCtrl> {
    
      final MyCounterModel model = MyCounterModel();
      final MyCounterView view = MyCounterView();
      final MyCounterCtrl ctrl = MyCounterCtrl();
    }
```

## modules/mycounter/my.counter.model.dart

```
    import 'package:mvcprovider/mvcprovider.dart';

    class MyCounterModel extends Model {

      int count = 0;
    }
```

## modules/mycounter/my.counter.ctrl.dart

```
    import 'package:mvcprovider/mvcprovider.dart';
    import 'my.counter.model.dart';

    class MyCounterCtrl extends Controller<MyCounterModel> {
    
      void increment() {
        model.count++;
        notifyListeners();
      }
    }
```

## modules/mycounter/my.counter.view.dart

```
    import 'package:flutter/material.dart';
    import 'package:mvcprovider/mvcprovider.dart';
    
    import 'my.counter.ctrl.dart';
    import 'my.counter.model.dart';

    class MyCounterView extends View<MyCounterModel, MyCounterCtrl> {
    
      @override
      Widget build(BuildContext context, [Widget child]) {
        super.build(context);
    
        return Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text("Counter : ${model.count}"),
            RaisedButton(
                child: Text("Increment"),
                onPressed: ctrl.increment,
            )
          ]
        );
      }
    }
```
